#!/bin/sh

CFG=~/.config/poorercputemp
arch=`uname -m`

load_module_func() {
	[ -z "$1" ] || mod=$1 # manually specified on cli
	#echo "test module" # COMMENT THIS IN PRODUCTION
	for m in ${mod} coretemp k10temp k8temp it87 lm85 nct6775 # more can be added
	do 
		#echo "$m" # COMMENT THIS IN PRODUCTION
		if lsmod|grep -q $m ;then # check if loaded
			modprobe $m 2>/dev/null # load if not already
		fi
		if check_temp_data_exists $m ;then # returns 0 on success
			return 0 # success, break here
		else
			rmmod $m 2>/dev/null # try to unload as it is useless to us
			continue # module failed, try next module
		fi
	done		
	# if we get here it failed
	echo "Can't load a temperature module"
	return 1
}

find_func() {
	#echo "searching" # COMMENT THIS IN PRODUCTION
	FILES="$1"
	for n in `echo $FILES`; do
		read p < $n
		if [ $? = 0 ];then
			FILE=$n # found it
			break
		else
			continue # didn't find, search again
		fi
	done
	# if we get here we didn't find anything useful
}

check_temp_data_exists() {
	#echo "checking data" # COMMENT THIS IN PRODUCTION
	MOD=${1}
	MPATH=`find /sys/devices -name 'name' | xargs grep "$MOD"`
	MPATH=${MPATH%/*}
	for a in `find $MPATH -type f -name "temp*_input"|sort` \
		`find /sys/devices/ -type f -name "temp"`
	do find_func "$a"
		[ -z "$FILE" ] && continue || break # if we found data break
	done
	if [ ! "$FILE" ];then
		echo "Failed to find file" && return 1 # bail out
	fi
	# if we get here we found it, so we write to file
	[ ! -d $CFG ] && mkdir $CFG
	echo -e "\"${FILE}\" is written to : \n$CFG/poorercputemprc"
	echo -n ${FILE} > $CFG/poorercputemprc # UNCOMMENT THIS IN PRODUCTION
	return 0
}

cputempfunc() {
	#echo "starting" # COMMENT THIS IN PRODUCTION
	if echo "$arch" | grep -qvE 'arm|aarch64' ;then
		load_module_func
		[ $? -ne 0 ] && exit 1
	else
		check_temp_data_exists
		return $?
	fi
	return 0
}

if [ -z "$1" ];then
	cputempfunc # start
else
	cli_mod=$1
	load_module_func $cli_mod # module specified on poorercputemp cli
fi
